==> snf_3.3.0_webrelease.tar.gz: snf_3.3.0_webrelease/src/snfdc/tmrslave.r <==
CC******************************************************************************
C   Copyright 1999 -- 2002 C. Kind, M. Reiher, J. Neugebauer, and B. A. Hess,
C   Chair of Theoretical Chemistry, Friedrich-Alexander-University 
C   Erlangen-Nuremberg, Egerlandstr. 3, D-91058 Erlangen, Germany.
C
C
C   This file is part of the package SNF.
C
C   SNF is free software; you can redistribute it and/or modify
C   it under the terms of the GNU General Public License as published by
C   the Free Software Foundation; either version 2 of the License, or
C   (at your option) any later version.
C
C   This program is distributed in the hope that it will be useful,
C   but WITHOUT ANY WARRANTY; without even the implied warranty of
C   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C   GNU General Public License for more details.
C
C   You should have received a copy of the GNU General Public License
C   along with this program; if not, write to the Free Software
C   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
C
CC******************************************************************************
      SUBROUTINE tmrslave(grad,co,ilab,nmode,freq,intonly,nummodes)
C>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
C re-written by J. Neugebauer, Uni Erlangen, 2003
CCH modified by C. Herrmann, Uni Bonn, 02/2005
C>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      include 'defs.h'
      include 'comm.h'
      include 'param.h'  

      integer ibuf,info,nn,iat,idum,ixyz,irc,idir,l,mypid
      integer idmy,j,mbuf,diraus,ldal,iclean,icleanl
      integer lprop,lpol,ldscf,lgrad,kstep,xprog,ldmol
      integer xeq,tmpxeq,icmp,idalmw,ldalmw
      integer xprogb,nit
      integer ilab(natoms)
      integer*4 itst,jstepa
      integer intonly,nummodes

      real*8 escf,gsum,cpu,wall,gcpu,gwall
      real*8 grad(nvar),dipol(3),co(3,natoms),polar(8,mxomeg)
      real*8 dipal(3),dipbe(3)
      real*8 nmode(maxmode,maxatoms*3),freq(maxmode)

      character*255 dalname
      character*10 prtype,calctype
      character*255 b1
      character*5 nic
      character*80 sdum,dalmw
      character*24 date,dmname
      character*255 dscfname,gradname,propname,polname

      logical found,snffast

C#    integer w,st(MPI_STATUS_SIZE)
C#    data w /MPI_COMM_WORLD/
 
      nic='nice '
      kstep=1

*---------------------------------------
* excited state calculation with egrad ?
*---------------------------------------
      if(rpast.gt.0) then
         if(exopt.eq.0) exopt=rpast
         write(iosl,*)  'No. of exc. states in egrad   = ',rpast
         write(iosl,*)  'State to be calculated in SNF = ',exopt
        if(smult.eq.1) then
          write(iosl,*) 'spin state of excited states  = singlet'
        else if(smult.eq.3) then
          write(iosl,*) 'spin state of excited states  = triplet'
        end if
      end if
 
*------------------
* restore MO vector
*------------------
      if (isuhf.EQ.0) then
       call getmos('mos',jstepa,mypid)
      else
       call getmos('alpha',jstepa,mypid)
       call getmos('beta',jstepa,mypid)
      end if  
 
*------------------------------------------------------------------------
* switch on archiving; make sure that the filename is followed by a blank
*------------------------------------------------------------------------
      if (isuhf.EQ.0) then
       call archiving(tempdir,'mos ',arpath,jstepa,1)
      else
       call archiving(tempdir,'alpha ',arpath,jstepa,1)
       call archiving(tempdir,'beta ',arpath,jstepa,2)
      end if

*-----------------------------------
* remove old output files (gradient)
*-----------------------------------
      irc=xeq('rm -rf '//tempdir(1:lt)//'/gradient')
      if(rpast.gt.0) then
         info=xeq('rm '//tempdir(1:lt)//'/sing_a')
         info=xeq('rm '//tempdir(1:lt)//'/trip_a')
      end if
      
      call rslave(co,ilab,jstepa,nmode,freq,intonly,nummodes)
*-------------------
* do the calculation
*-------------------
      call prog_type(progno,prtype)
      call calc_type(progno,calcno,calctype)
      write (iosl,*) 'progno : ',progno
      write (iosl,*) 'calcno : ',calcno
      write (iosl,'(2a)') ' program package for single points is: ',
     *  prtype
      write (iosl,'(2a)') ' type of calculation : ',calctype
      if(snffast) then
        nic='     '
        write (iosl,*) '** found $snffast flag: omitting command nice'
      end if
      call flush(iosl)

          call augnum(propname,'dip.out.',jstepa)
          call llen(propname,lprop)

      if (calcno.eq.1.or.calcno.eq.3.or.calcno.eq.4) then

C-----------------------------
C first task: dscf calculation
C-----------------------------
        call augnum(dscfname,'dscf.out.',jstepa)
        call llen(dscfname,ldscf)
        info=xprog(nic(1:5)//progdir(1:lb)//'dscf',dscfname(1:ldscf))
        call archiving(tempdir,'whatever ',arpath,0,0)

C------------------------------------------------------------------
C second (& third) task: gradient and dipole moment calculation ...
C------------------------------------------------------------------
        call augnum(gradname,'grad.out.',jstepa)
        call llen(gradname,lgrad)

C-------------------------------------------------
C ... using egrad for excited states (HF/DFT), ...
C-------------------------------------------------
        if(calcno.eq.1.and.rpast.gt.0) then
          info=xprog(nic(1:5)//progdir(1:lb)//'egrad',
     *         gradname(1:lgrad))
          call getexdip(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C-------------------------
C ... rimp2 for RIMP2, ...
C-------------------------
        else if(calcno.eq.3) then
          info=xprog(nic(1:5)//progdir(1:lb)//'rimp2',
     *         gradname(1:lgrad))
          call getdipmp2(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C------------------------
C ... mpgrad for MP2, ...
C------------------------
        else if(calcno.eq.4) then
          info=xprog(nic(1:5)//progdir(1:lb)//'mpgrad',
     *        gradname(1:lgrad))
          call getdipmp2(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C---------------------------------------
C ... or grad for ground states (HF/DFT)
C---------------------------------------
        else
          info=xprog(nic(1:5)//progdir(1:lb)//'grad',gradname(1:lgrad))
        end if
      else if (calcno.eq.2) then

*------------------------------
* first task: ridft calculation
*------------------------------
        call augnum(dscfname,'ridft.out.',jstepa)
        call llen(dscfname,ldscf)
        info=xprog(nic(1:5)//progdir(1:lb)//'ridft',dscfname(1:ldscf))
        call archiving(tempdir,'whatever ',arpath,0,0)
        call augnum(gradname,'rdgrad.out.',jstepa)
        call llen(gradname,lgrad)
*--------------------------------
* second task: rdgrad calculation
*--------------------------------
        info=xprog(nic(1:5)//progdir(1:lb)//'rdgrad',gradname(1:lgrad))
      end if
*--------------------------------------------------------------------------------
* end of energy/gradient(/dipole) moment section
*--------------------------------------------------------------------------------

      if(calcno.eq.1.or.calcno.eq.2) then
*---------------------------------------------------------
* separate calculation of dipole moment and polarizability
* [1] dipole moment
*---------------------------------------------------------
        if (isuhf.EQ.0) THEN
CJN       info=xprog(nic(1:5)//progdir(1:lb)//'moloch',
CJN  *      propname(1:lprop))
          info=xprogb(nic(1:5)//progdir(1:lb)//'moloch',
     *      propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            call getdip(dipol,tempdir(1:lt)//'/control')
          end if
        else
*-------------------------------------------------------------------------
* for UHF cases, calculate dipol moment as arithmetic mean of calculations
* with closed-shell occupations set to either alpha or beta occupations;
* to accomplish that, change control file accordingly, and then copy alpha
* or beta MO file to <mos>, changing the tags accordingly
*-------------------------------------------------------------------------
          call fudge_control('$alpha shells',tempdir(1:lt))
          call fudge_mos(tempdir(1:lt),'alpha')
CMR170202          info=xprog(progdir(1:lb)//'moloch',propname(1:lprop))
          info=xprogb(progdir(1:lb)//'moloch',propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            CALL getdip(dipal,tempdir(1:lt)//'/control')
          end if
          irc=xeq('cp '//tempdir(1:lt)//'/control '//tempdir(1:lt)//
     &        '/control.bu')
          if (irc.NE.0) THEN
            write (iosl,*) 'rslave: difficulties copying control'
            write (iosl,*) 'rslave: RC=',irc
            call flush(iosl)
            return
          end if
          call fudge_control('$beta shells',tempdir(1:lt))
          call fudge_mos(tempdir(1:lt),'beta')
CMR170202          info=xprog(progdir(1:lb)//'moloch',propname(1:lprop))
          info=xprogb(progdir(1:lb)//'moloch',propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            call getdip(dipbe,tempdir(1:lt)//'/control')
            do icmp=1,3
              dipol(icmp)=0.5d0*(dipal(icmp)+dipbe(icmp))
            end do
          end if
        end if

*---------------------
* [2] polarizability ?
*---------------------
        if (ipol.ge.1) then
          call augnum(polname,'pol.out.',jstepa)
          call llen(polname,lpol)
          call archiving(tempdir,'nconvx ',arpath,jstepa,1)
          call getarch('nconvx ',jstepa,mypid,irc)
          info=xprog(nic(1:5)//progdir(1:lb)//'escf',polname(1:lpol))
          call archiving(tempdir,'whatever ',arpath,0,0)
          call getpol(polar,tempdir(1:lt)//'/'//polname(1:lpol))
        end if
      end if
*------------------------------------------------
* end of dipole moment/polarizability calculation
*------------------------------------------------

      write(iosl,*) '** tmrslave: all calculations done ...'
      call flush(iosl)
      call rxxxx(dscfname,nit,cpu,wall)
      call rxxxx(gradname,idmy,gcpu,gwall)
      write (iosl,*) 'iterations: ',nit
      write (iosl,*) 'cpu       : ',cpu,gcpu
      write (iosl,*) 'wall      : ',wall,gwall

      call flush(iosl)
      call mnotify(5,mypid,6,'times read',10)

      call findstr(tempdir(1:lt)//'/control','$actual',found)
      if (found) then
        call mnotify(5,mypid,7,'$actual found',13)
        write (iosl,*)
     *   '$actual found in control file ... shutting down node'
        call flush(iosl)
        call slshutdown(1,tid0,mytid)
      end if

70    continue

*----------------------------
* read and save gradient file
*----------------------------
        call getgrad(natoms,escf,grad,tempdir(1:lt)//'/gradient')
        call augnum(gradname,tempdir(1:lt)//'/gradient.',jstepa)
        call llen(gradname,lgrad)
        irc=xeq('mv '//tempdir(1:lt)//'/gradient '//gradname(1:lgrad))

      call mnotify(5,mypid,5,'results read',12)

*------------------------
* calculate gradient norm
*------------------------
      gsum=0.0d0
      do j=1,nvar    
         gsum=gsum+grad(j)**2
      enddo
      write (iosl,*) 'grad norm',gsum
      call flush(iosl)

*---------------------------------
* error in TURBOMOLE calculation ?
*---------------------------------
      call clean(sdum)
      call findstr(tempdir(1:lt)//'/control','$actual',found)
999   if (found) then
        call mnotify(5,mypid,8,'results weird',13)
        escf=999.D0
      end if

*-------------------
* send final results
*-------------------
C:      call MPI_SSEND(nit,1,MPI_INTEGER,tid0,fsys_restag,w,info)
C:      call mpierr('MPI_SSEND nit','rslave',info)
C:      call MPI_SSEND(cpu,1,MPI_DOUBLE_PRECISION,tid0,801,w,info)
C:      call mpierr('MPI_SSEND cpu','rslave',info)
C:      call MPI_SSEND(wall,1,MPI_DOUBLE_PRECISION,tid0,802,w,info)
C:      call mpierr('MPI_SSEND wall','rslave',info)
C:      call MPI_SSEND(gcpu,1,MPI_DOUBLE_PRECISION,tid0,803,w,info)
C:      call mpierr('MPI_SSEND gcpu','rslave',info)
C:      call MPI_SSEND(gwall,1,MPI_DOUBLE_PRECISION,tid0,804,w,info)
C:      call mpierr('MPI_SSEND gwall','rslave',info)
C:      call MPI_SSEND(escf,1,MPI_DOUBLE_PRECISION,tid0,805,w,info)
C:      call mpierr('MPI_SSEND out1','rslave',info)
C:      call MPI_SSEND(dipol,3,MPI_DOUBLE_PRECISION,tid0,806,w,info)
C:      call mpierr('MPI_SSEND dipol','rslave',info)
C:      call MPI_SSEND(grad,nvar,MPI_DOUBLE_PRECISION,
C:   *   tid0,807,w,info)
C:      call mpierr('MPI_SSEND escf','rslave',info)
C:      IF (ipol.GT.0) THEN
C:       call MPI_SSEND(polar,8*ipol,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND polar','rslave',info)
C:      end if
C//SKIPC:
C#      call MPI_SEND(nit,1,MPI_INTEGER,tid0,fsys_restag,w,info)
C#      call mpierr('MPI_SEND nit','rslave',info)
C#      call MPI_SEND(cpu,1,MPI_DOUBLE_PRECISION,tid0,801,w,info)
C#      call mpierr('MPI_SEND cpu','rslave',info)
C#      call MPI_SEND(wall,1,MPI_DOUBLE_PRECISION,tid0,802,w,info)
C#      call mpierr('MPI_SEND wall','rslave',info)
C#      call MPI_SEND(gcpu,1,MPI_DOUBLE_PRECISION,tid0,803,w,info)
C#      call mpierr('MPI_SEND gcpu','rslave',info)
C#      call MPI_SEND(gwall,1,MPI_DOUBLE_PRECISION,tid0,804,w,info)
C#      call mpierr('MPI_SEND gwall','rslave',info)
C#      call MPI_SEND(escf,1,MPI_DOUBLE_PRECISION,tid0,805,w,info)
C#      call mpierr('MPI_SEND escf','rslave',info)
C#      call MPI_SEND(dipol,3,MPI_DOUBLE_PRECISION,tid0,806,w,info)
C#      call mpierr('MPI_SEND dipol','rslave',info)
C#      call MPI_SEND(grad,nvar,MPI_DOUBLE_PRECISION,
C#   *   tid0,807,w,info)
C#      call mpierr('MPI_SEND grad','rslave',info)
C#      if (ipol.GT.0) then
C#       call MPI_SEND(polar,8*ipol,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND polar','rslave',info)
C#      end if
C//END
C//SKIPC#
      call PVMFINITSEND(PVMDATADEFAULT,MBUF)
      call PVMFPACK(INTEGER4,nit,kstep,1,info)
      call PVMFPACK(REAL8,cpu,kstep,1,info)
      call PVMFPACK(REAL8,wall,kstep,1,info)
      call PVMFPACK(REAL8,gcpu,kstep,1,info)
      call PVMFPACK(REAL8,gwall,kstep,1,info)
      call PVMFPACK(REAL8,escf,1,1, INFO )
      call PVMFPACK(REAL8,dipol,3,1,INFO )
      call PVMFPACK(REAL8,grad,nvar,1,INFO )
      IF (ipol.GT.0) call PVMFPACK(REAL8,polar,8*ipol,1,INFO )
      call PVMFSEND( TID0, 0, INFO )
C//END
      call mnotify(5,mypid,9,'results sent',12)
      return
      end

==> snf-4.0.0_webrelease.tar.gz: snf-4.0.0_webrelease/src/snfdc/tmrslave.r <==
CC******************************************************************************
C   Copyright 1999 -- 2002 C. Kind, M. Reiher, J. Neugebauer, and B. A. Hess,
C   Chair of Theoretical Chemistry, Friedrich-Alexander-University 
C   Erlangen-Nuremberg, Egerlandstr. 3, D-91058 Erlangen, Germany.
C
C
C   This file is part of the package SNF.
C
C   SNF is free software; you can redistribute it and/or modify
C   it under the terms of the GNU General Public License as published by
C   the Free Software Foundation; either version 2 of the License, or
C   (at your option) any later version.
C
C   This program is distributed in the hope that it will be useful,
C   but WITHOUT ANY WARRANTY; without even the implied warranty of
C   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C   GNU General Public License for more details.
C
C   You should have received a copy of the GNU General Public License
C   along with this program; if not, write to the Free Software
C   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
C
CC******************************************************************************
      SUBROUTINE tmrslave(grad,co,ilab,nmode,freq,intonly,nummodes)

c     ====================================================================
c     purpose: perform a MOLPRO single point calculation for a displaced
c              structure, collect the results, and send them to master
c 
c     history:
c       - written by J. Neugebauer, Uni Erlangen, 2003, based on 
c         routine rslave by B.A. Hess
c       - modified by C. Herrmann, Uni Bonn, 02/2005
c       - modified by S. Luber, ETH Zurich, 2006
c       - cleaned and modified by J. Neugebauer, ETH Zurich, 01/2007
c     ====================================================================

      include 'defs.h'
      include 'param.h'  

      integer info,irc,l
      integer idmy,j
      integer xeq,tmpxeq,icmp
      integer xprogb,xprog
      integer ilab(natoms)
      integer*4 itst,jstepa,nit
      integer intonly,nummodes,lprop,lgrad,ldscf,lpol

      real*8 escf,cpu,wall,gcpu,gwall
      real*8 grad(nvar),dipol(3),co(3,natoms),polar(8,mxomeg)
      real*8 gtenlao(9,mxomeg),gtenao(9,mxomeg),aten(27,mxomeg)
      real*8 dipal(3),dipbe(3)
      real*8 nmode(maxmode,maxatoms*3),freq(maxmode)

      character*10 prtype,calctype
      character*255 b1
      character*5 nic
      character*255 dscfname,gradname,propname,polname

      logical found,vroaflag

      vroaflag=.false.
      if ((ipol-1000).ge.0) vroaflag=.true.
 
*---------------------------------------
* excited state calculation with egrad ?
*---------------------------------------
      if(rpast.gt.0) then
         if(exopt.eq.0) exopt=rpast
         write(iosl,*)  'No. of exc. states in egrad   = ',rpast
         write(iosl,*)  'State to be calculated in SNF = ',exopt
        if(smult.eq.1) then
          write(iosl,*) 'spin state of excited states  = singlet'
        else if(smult.eq.3) then
          write(iosl,*) 'spin state of excited states  = triplet'
        end if
      end if
 
*------------------
* restore MO vector
*------------------
      if (isuhf.EQ.0) then
       call getmos('mos',jstepa,mytid)
      else
       call getmos('alpha',jstepa,mytid)
       call getmos('beta',jstepa,mytid)
      end if  
 
*------------------------------------------------------------------------
* switch on archiving; make sure that the filename is followed by a blank
*------------------------------------------------------------------------
      if (isuhf.EQ.0) then
       call archiving(tempdir,'mos ',arpath,jstepa,1)
      else
       call archiving(tempdir,'alpha ',arpath,jstepa,1)
       call archiving(tempdir,'beta ',arpath,jstepa,2)
      end if

*-----------------------------------
* remove old output files (gradient)
*-----------------------------------
      irc=xeq('rm -rf '//tempdir(1:lt)//'/gradient')
      if(rpast.gt.0) then
         info=xeq('rm '//tempdir(1:lt)//'/sing_a')
         info=xeq('rm '//tempdir(1:lt)//'/trip_a')
      end if
      
      call rslave(co,ilab,jstepa,nmode,freq,intonly,nummodes,nic)

*-------------------
* do the calculation
*-------------------
      call prog_type(progno,prtype)
      call calc_type(progno,calcno,calctype)

      call augnum(propname,'dip.out.',jstepa)
      call llen(propname,lprop)

      if (calcno.eq.1.or.calcno.eq.3.or.calcno.eq.4.or.calcno.eq.5.or
     *.calcno.eq.7) then

C-----------------------------
C first task: dscf calculation
C-----------------------------
        call augnum(dscfname,'dscf.out.',jstepa)
        call llen(dscfname,ldscf)
        info=xprog(nic(1:5)//progdir(1:lb)//'dscf',dscfname(1:ldscf))
        call archiving(tempdir,'whatever ',arpath,0,0)

C------------------------------------------------------------------
C second (& third) task: gradient and dipole moment calculation ...
C------------------------------------------------------------------
        call augnum(gradname,'grad.out.',jstepa)
        call llen(gradname,lgrad)

C-------------------------------------------------
C ... using egrad for excited states (HF/DFT), ...
C-------------------------------------------------
        if(calcno.eq.5) then
          info=xprog(nic(1:5)//progdir(1:lb)//'egrad',gradname(1:lgrad))
          call getexdip(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C-------------------------
C ... rimp2 for RIMP2, ...
C-------------------------
        else if(calcno.eq.3) then
          info=xprog(nic(1:5)//progdir(1:lb)//'rimp2',
     *         gradname(1:lgrad))
          call getdipmp2(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C------------------------
C ... mpgrad for MP2, ...
C------------------------
        else if(calcno.eq.4) then
          info=xprog(nic(1:5)//progdir(1:lb)//'mpgrad',
     *        gradname(1:lgrad))
          call getdipmp2(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C------------------------
C ... ricc2 for RICC2, ...
C------------------------
        else if(calcno.eq.7) then
          info=xprog(nic(1:5)//progdir(1:lb)//'ricc2',
     *        gradname(1:lgrad))
          call getdipcc2(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))

C---------------------------------------
C ... or grad for ground states (HF/DFT)
C---------------------------------------
        else
          if(nummodes.eq.0) info=xprog(nic(1:5)//progdir(1:lb)//'grad',
     *                           gradname(1:lgrad))
        end if
      else if (calcno.eq.2.or.calcno.eq.6) then

*------------------------------
* first task: ridft calculation
*------------------------------
        call augnum(dscfname,'ridft.out.',jstepa)
        call llen(dscfname,ldscf)
        info=xprog(nic(1:5)//progdir(1:lb)//'ridft',dscfname(1:ldscf))
        call archiving(tempdir,'whatever ',arpath,0,0)
        call augnum(gradname,'rdgrad.out.',jstepa)
        call llen(gradname,lgrad)

*--------------------------------
* second task: rdgrad calculation
*--------------------------------
        if(nummodes.eq.0) then
          if(calcno.eq.2) then
            info=xprog(nic(1:5)//progdir(1:lb)//'rdgrad',
     *           gradname(1:lgrad))

C-------------------------------------------------
C ... or: egrad for excited states (RI-DFT), ...
C-------------------------------------------------

          else if(calcno.eq.6) then
            info=xprog(nic(1:5)//progdir(1:lb)//'egrad',gradname(1:lgrad))
            call getexdip(dipol,tempdir(1:lt)//'/'//gradname(1:lgrad))
          end if
        end if
      else
        call errex('tmrslave: unknown calculation type')
      end if
*--------------------------------------------------------------------------------
* end of energy/gradient(/dipole) moment section
*--------------------------------------------------------------------------------

      if(calcno.eq.1.or.calcno.eq.2) then
*---------------------------------------------------------
* separate calculation of dipole moment and polarizability
* [1] dipole moment
*---------------------------------------------------------
        if (isuhf.EQ.0) THEN
CJN       info=xprog(nic(1:5)//progdir(1:lb)//'moloch',
CJN  *      propname(1:lprop))
          info=xprogb(nic(1:5)//progdir(1:lb)//'moloch',
     *      propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            call getdip(dipol,tempdir(1:lt)//'/control')
          end if
        else
*-------------------------------------------------------------------------
* for UHF cases, calculate dipol moment as arithmetic mean of calculations
* with closed-shell occupations set to either alpha or beta occupations;
* to accomplish that, change control file accordingly, and then copy alpha
* or beta MO file to <mos>, changing the tags accordingly
*-------------------------------------------------------------------------
          call fudge_control('$alpha shells',tempdir(1:lt))
          call fudge_mos(tempdir(1:lt),'alpha')
CMR170202          info=xprog(progdir(1:lb)//'moloch',propname(1:lprop))
          info=xprogb(progdir(1:lb)//'moloch',propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            CALL getdip(dipal,tempdir(1:lt)//'/control')
          end if
          irc=xeq('cp '//tempdir(1:lt)//'/control '//tempdir(1:lt)//
     &        '/control.bu')
          if (irc.NE.0) THEN
            write (iosl,*) 'rslave: difficulties copying control'
            write (iosl,*) 'rslave: RC=',irc
            call flush(iosl)
            return
          end if
          call fudge_control('$beta shells',tempdir(1:lt))
          call fudge_mos(tempdir(1:lt),'beta')
CMR170202          info=xprog(progdir(1:lb)//'moloch',propname(1:lprop))
          info=xprogb(progdir(1:lb)//'moloch',propname(1:lprop))
          call actest('moloch',found)
          if((info.eq.0).and.(.not.found)) then
            call getdip(dipbe,tempdir(1:lt)//'/control')
            do icmp=1,3
              dipol(icmp)=0.5d0*(dipal(icmp)+dipbe(icmp))
            end do
          end if
        end if

*---------------------------------------
* [2] polarizability, G- and A-tensor ?
*--------------------------------------
        if (ipol.ge.1) then
          call augnum(polname,'pol.out.',jstepa)
          call llen(polname,lpol)
          call archiving(tempdir,'nconvx ',arpath,jstepa,1)
          call getarch('nconvx ',jstepa,mytid,irc)
          info=xprog(nic(1:5)//progdir(1:lb)//'escf',polname(1:lpol))
          call archiving(tempdir,'whatever ',arpath,0,0)
          if (vroaflag) then
            call gettmvroa(polar,gtenlao,gtenao,aten,
     *       tempdir(1:lt)//'/'//polname(1:lpol))
          else
            call getpol(polar,tempdir(1:lt)//'/'//polname(1:lpol))
          end if
        end if
      end if
*------------------------------------------------
* end of dipole moment/polarizability calculation
*------------------------------------------------

      write(iosl,*) '** tmrslave: all calculations done ...'
      call flush(iosl)
      call rtm_it_time(dscfname,nit,cpu,wall)
      call rtm_it_time(gradname,idmy,gcpu,gwall)

      call mnotify(5,mytid,6,'times read',10)

      call findstr(tempdir(1:lt)//'/control','$actual',found)
      if (found) then
        call mnotify(5,mytid,7,'$actual found',13)
        write (iosl,*)
     *   '$actual found in control file ... shutting down node'
        call flush(iosl)
        call slshutdown(1,tid0,mytid)
      end if

70    continue

*----------------------------
* read and save gradient file
*----------------------------
      if(nummodes.eq.0) then
        call getgrad(natoms,escf,grad,tempdir(1:lt)//'/gradient')
        call augnum(gradname,tempdir(1:lt)//'/gradient.',jstepa)
        call llen(gradname,lgrad)
        irc=xeq('mv '//tempdir(1:lt)//'/gradient '//gradname(1:lgrad))
        call mnotify(5,mytid,5,'results read',12)
      end if

*---------------------------------
* error in TURBOMOLE calculation ?
*---------------------------------
      call findstr(tempdir(1:lt)//'/control','$actual',found)
999   if (found) then
        call mnotify(5,mytid,8,'results weird',13)
        escf=999.D0
      end if

c     ------------------
c     send final results
c     ------------------
      call sendres(nit,cpu,wall,gcpu,gwall,escf,dipol,grad,
     *   polar,gtenlao,gtenao,aten,jstepa,nummodes,intonly)

      return
      end
